==> genometools_1.5.10+ds.orig.tar.xz: genometools-1.5.10/src/match/rdj-contigs-writer.h <==
/*
  Copyright (c) 2011 Giorgio Gonnella <gonnella@zbh.uni-hamburg.de>
  Copyright (c) 2011 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef RDJ_CONTIGS_WRITER_H
#define RDJ_CONTIGS_WRITER_H

#include "core/encseq.h"
#include "core/file.h"
#include "core/logger.h"

typedef struct GtContigsWriter GtContigsWriter;

GtContigsWriter* gt_contigs_writer_new(const GtEncseq *reads,
                                       GtFile *outfp);

void             gt_contigs_writer_delete(GtContigsWriter *contigs_writer);

void             gt_contigs_writer_enable_complete_path_output(
                                             GtContigsWriter *contigs_writer);

void             gt_contigs_writer_enable_astat_calculation(
                                             GtContigsWriter *contigs_writer,
                                             double coverage,
                                             unsigned char *rcn,
                                             FILE *depthinfo_fp);

void             gt_contigs_writer_start(GtContigsWriter *contigs_writer,
                                         GtUword seqnum);

void             gt_contigs_writer_append(GtContigsWriter *contigs_writer,
                                          GtUword seqnum,
                                          GtUword nofchars);

void             gt_contigs_writer_write(GtContigsWriter *contigs_writer);

void             gt_contigs_writer_abort(GtContigsWriter *contigs_writer);

void             gt_contigs_writer_show_stats(GtContigsWriter *contigs_writer,
                                              GtLogger *logger);

#endif

==> genometools_1.6.2+ds.orig.tar.xz: genometools-1.6.2/src/match/rdj-contigs-writer.h <==
/*
  Copyright (c) 2011 Giorgio Gonnella <gonnella@zbh.uni-hamburg.de>
  Copyright (c) 2011 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef RDJ_CONTIGS_WRITER_H
#define RDJ_CONTIGS_WRITER_H

#include "core/encseq.h"
#include "core/file_api.h"
#include "core/logger.h"

typedef struct GtContigsWriter GtContigsWriter;

GtContigsWriter* gt_contigs_writer_new(const GtEncseq *reads,
                                       GtFile *outfp);

void             gt_contigs_writer_delete(GtContigsWriter *contigs_writer);

void             gt_contigs_writer_enable_complete_path_output(
                                             GtContigsWriter *contigs_writer);

void             gt_contigs_writer_enable_astat_calculation(
                                             GtContigsWriter *contigs_writer,
                                             double coverage,
                                             unsigned char *rcn,
                                             FILE *depthinfo_fp);

void             gt_contigs_writer_start(GtContigsWriter *contigs_writer,
                                         GtUword seqnum);

void             gt_contigs_writer_append(GtContigsWriter *contigs_writer,
                                          GtUword seqnum,
                                          GtUword nofchars);

void             gt_contigs_writer_write(GtContigsWriter *contigs_writer);

void             gt_contigs_writer_abort(GtContigsWriter *contigs_writer);

void             gt_contigs_writer_show_stats(GtContigsWriter *contigs_writer,
                                              GtLogger *logger);

#endif
